@@ -13,7 +13,11 @@ class CouchBackend(object):
 
     def get_user(self, user_id):
         try:
-            return User(self.db[user_id], _db = self.db)
+            user = self.db[user_id]
+            if len(self.db.view(settings.COUCHDB_AUTH_VIEW, key=user.username, limit=1).rows):
+                return User(self.db[user_id], _db = self.db)
+            else:
+                return None
         except ResourceNotFound:
             return None
         
